Download freshwater recreational fishery creel datasets from Washington's public data warehouse, data.wa.gov. When a valid 'fishery_name' is provided several database views are downloaded (i.e., effort, interview, catch, water bodies, closures, and a )
Arguments
- fishery_name
Identifier which represents the spatiotemporal configuration for a given dataset with associated fishery closures.
Logical TRUE/FALSE that toggles whether a summary table prints in the console reporting the number of rows per table downloaded. Useful as a quick check to see if anything was downloaded.
Value
dwg, a list object containing a dataframe for each database view downloaded (e.g., effort, interview, catch)
See also
Other public_data:
fetch_fishery_names(),
get_fishery_data(),
query_creel_website(),
search_fishery_name()