Removes specified sections from all components of a creel survey dataset, including interview, effort, catch, and days tables.
Value
A modified list with the same structure as data, with specified
sections removed from all applicable tables. Also removes corresponding
open_section_X columns from the days table.
Examples
if (FALSE) { # \dontrun{
# Drop a single section
data_filtered <- drop_section(data, section = 3)
# Drop multiple sections
data_filtered <- drop_section(data, section = c(1, 2))
} # }